/*
  This file is part of "Scopa" - An italian card game.
  Copyright (C) 2007  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include "Player.h"

Player::~Player()
{
  // no code
}

void Player::Initialize()
{
  hand.clear();
}

bool Player::HasCardsInHand() const
{
  return !hand.empty();
}

void Player::PutCard(const Card& card)
{
  hand.push_back(card);

}

void Player::CardsPlayed(std::vector<Card>& cards,
                         bool ownCards,
                         size_t round)
{
  // no code
}

void Player::RoundFinished(size_t round, size_t pointsMe, size_t pointsOther)
{
  // no code
}

void Player::PrintStatistics()
{
  // no code
}


